@@ -31,28 +31,28 @@ Data                      data;
 Lum::Model::CalendarRef   date=new Lum::Model::Calendar();
 Lum::Model::TimeRef       timestamp=new Lum::Model::Time(Lum::Base::Time());
 
-Lum::Model::SizeTRef      currentTab=new Lum::Model::SizeT(1);
+Lum::Model::ULongRef      currentTab=new Lum::Model::ULong(1);
 
-Lum::Model::SizeTRef      topWeight=new Lum::Model::SizeT(1500);
-Lum::Model::SizeTRef      bottomWeight=new Lum::Model::SizeT(0);
-Lum::Model::SizeTRef      maxWeight=new Lum::Model::SizeT(1500);
-Lum::Model::SizeTRef      minWeight=new Lum::Model::SizeT(0);
+Lum::Model::ULongRef      topWeight=new Lum::Model::ULong(1500);
+Lum::Model::ULongRef      bottomWeight=new Lum::Model::ULong(0);
+Lum::Model::ULongRef      maxWeight=new Lum::Model::ULong(1500);
+Lum::Model::ULongRef      minWeight=new Lum::Model::ULong(0);
 
-Lum::Model::SizeTRef      topValue=new Lum::Model::SizeT(400);
-Lum::Model::SizeTRef      bottomValue=new Lum::Model::SizeT(0);
-Lum::Model::SizeTRef      maxValue=new Lum::Model::SizeT(250);
-Lum::Model::SizeTRef      minValue=new Lum::Model::SizeT(150);
+Lum::Model::ULongRef      topValue=new Lum::Model::ULong(400);
+Lum::Model::ULongRef      bottomValue=new Lum::Model::ULong(0);
+Lum::Model::ULongRef      maxValue=new Lum::Model::ULong(250);
+Lum::Model::ULongRef      minValue=new Lum::Model::ULong(150);
 
-Lum::Model::SizeTRef      goodValueLimit=new Lum::Model::SizeT(10);
-Lum::Model::SizeTRef      badValueLimit=new Lum::Model::SizeT(30);
+Lum::Model::ULongRef      goodValueLimit=new Lum::Model::ULong(10);
+Lum::Model::ULongRef      badValueLimit=new Lum::Model::ULong(30);
 
-Lum::Model::SizeTRef      refValue=new Lum::Model::SizeT(1300);
+Lum::Model::ULongRef      refValue=new Lum::Model::ULong(1300);
 
 Lum::Model::StringRef     valueUnit=new Lum::Model::String(L"badness");
 Lum::Model::StringRef     weightUnit=new Lum::Model::String(L"kg");
 
-Lum::Model::SizeTRef      trendType=new Lum::Model::SizeT(trendTwoWeeks);
-Lum::Model::SizeTRef      trendDirection=new Lum::Model::SizeT(1);
+Lum::Model::ULongRef      trendType=new Lum::Model::ULong(trendTwoWeeks);
+Lum::Model::ULongRef      trendDirection=new Lum::Model::ULong(1);
 
 bool Entry::operator==(const Entry& entry) const
 {
