@@ -45,11 +45,11 @@ Diagram::Diagram()
    warnColor(1.0,0.0,0.0,Lum::OS::display->blackColor),
    limitColor(1.0,0.0,0.0,Lum::OS::display->blackColor),
    valueGoodColor(0.95,0.95,0.95,Lum::OS::display->blackColor),
-   valueGoodFrameColor(0.64,0.64,0.64,Lum::OS::display->blackColor),
+   valueGoodFrameColor(0.8,0.8,0.8,Lum::OS::display->blackColor),
    valueBadColor(1.0,0.82,0.82,Lum::OS::display->blackColor),
    valueBadFrameColor(0.8,0.58,0.58,Lum::OS::display->blackColor),
-   scaleColor(0.7,0.7,0.7,Lum::OS::display->blackColor),
-   textColor(0.7,0.7,0.7,Lum::OS::display->blackColor),
+   labelColor(0.3,0.3,0.3,Lum::OS::display->blackColor),
+   scaleColor(0.9,0.9,0.9,Lum::OS::display->blackColor),
    font(Lum::OS::display->GetFont(Lum::OS::Display::fontScaleFootnote)),
    mode(modeFullDay)
 {
@@ -147,6 +147,7 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
 {
   int                                                xPos=this->x+((hAdjustment->GetTop()-1)/dayWidth)*
                                                           dayWidth-(hAdjustment->GetTop()-1);
+  std::map<Lum::Base::Calendar,Day*>::const_iterator startIter;
   std::map<Lum::Base::Calendar,Day*>::const_iterator iter;
   bool                                               pointsDrawn=false; // We have drawn at least one point
   bool                                               pastEnd=false;     // We have beenmoved past the visible end
@@ -155,14 +156,14 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
   Lum::Base::Calendar                                day;
   size_t                                             lastWeight=0;
 
-  iter=data.data.lower_bound(start);
-  while (iter!=data.data.begin()) {
+  startIter=data.data.lower_bound(start);
+  while (startIter!=data.data.begin()) {
     bool hasPoint=false;
 
-    --iter;
+    --startIter;
 
-    for (std::list<Entry>::const_iterator entry=iter->second->entries.begin();
-         entry!=iter->second->entries.end();
+    for (std::list<Entry>::const_iterator entry=startIter->second->entries.begin();
+         entry!=startIter->second->entries.end();
          ++entry) {
       if (entry->item.empty()) {
         hasPoint=true;
@@ -175,7 +176,7 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
     }
   }
 
-  while (iter!=data.data.end() && !finished) {
+  for (iter=startIter; iter!=data.data.end() && !finished; ++iter) {
     int   days;
     Value value=0;
 
@@ -184,10 +185,6 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
     // diagram borders
     //
 
-    if (iter->first>end) {
-      pastEnd=true;
-    }
-
     days=0;
     day=start;
     if (day<=iter->first) {
@@ -237,6 +234,35 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
                           dayWidth,height-TransformValue(value));
       draw->PopForeground();
     }
+  }
+
+  pastEnd=false;
+  for (iter=startIter; iter!=data.data.end() && !finished; ++iter) {
+    int days;
+
+    //
+    // Detect first weight points to the left and right of the
+    // diagram borders
+    //
+
+    if (iter->first>end) {
+      pastEnd=true;
+    }
+
+    days=0;
+    day=start;
+    if (day<=iter->first) {
+      while (day!=iter->first) {
+        day.AddDays(1);
+        days++;
+      }
+    }
+    else {
+      while (day!=iter->first) {
+        day.AddDays(-1);
+        days--;
+      }
+    }
 
     //
     // Draw weight points
@@ -278,7 +304,7 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
           lx2=cx;
           ly2=cy;
 
-          if (!(lx1<this->x && lx2<this->x) && cx!=px) {
+          if (!(lx1<this->x && lx2<this->x)) {
             // Point outside diagram: Interpolate position on left diagram border
             if (lx1<this->x) {
               lx1=this->x;
@@ -287,8 +313,14 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
 
             // Point outside diagram: Interpolate position on right diagram border
             if (lx2>this->x+(int)this->width-1) {
-              lx2=this->x+(int)this->width-1;
-              ly2=((lx2-px)*(cy-py))/(cx-px)+py;
+              if (cx!=px) {
+                lx2=this->x+(int)this->width-1;
+                ly2=((lx2-px)*(cy-py))/(cx-px)+py;
+              }
+              else {
+                lx2=this->x+(int)this->width-1;
+                ly2=ly1;
+              }
             }
 
             if(lastWeight<minWeight->Get() || lastWeight>maxWeight->Get() ||
@@ -316,38 +348,23 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
         }
       }
     }
-
-    ++iter;
   }
 }
 
-void Diagram::PrintHorizontalScale(Lum::OS::DrawInfo* draw,
+void Diagram::PrintHorizontalLabel(Lum::OS::DrawInfo* draw,
                                    size_t dayWidth,
                                    const Lum::Base::Calendar& start)
 {
   std::wstring        tmp;
   Lum::Base::Calendar day;
 
-  draw->PushFont(font);
-
   draw->PushClip(this->x+weightUnitWidth,this->y,this->width-weightUnitWidth-valueUnitWidth,this->height);
+  draw->PushFont(font);
+  draw->PushForeground(labelColor);
 
   day=start;
   int xPos=this->x+((hAdjustment->GetTop()-1)/dayWidth)*dayWidth-(hAdjustment->GetTop()-1);
   while (xPos<this->x+(int)width) {
-
-    draw->PushForeground(scaleColor);
-    switch (mode) {
-    case modeFullDay:
-    case modeSmallDay:
-      draw->DrawLine(xPos+dayWidth-1,this->y,xPos+dayWidth-1,this->y+height-1);
-      break;
-    default:
-      break;
-    }
-    draw->PopForeground();
-
-    draw->PushForeground(textColor);
     switch (mode) {
     case modeFullDay:
       tmp=Lum::Base::Calendar::GetWeekDayNameShort(day.GetDayOfWeek());
@@ -376,23 +393,57 @@ void Diagram::PrintHorizontalScale(Lum::OS::DrawInfo* draw,
       }
       break;
     }
-    draw->PopForeground();
 
     day.AddDays(1);
     xPos+=dayWidth;
   }
 
+  draw->PopForeground();
+  draw->PopFont();
   draw->PopClip();
 
-  draw->PopFont();
+}
+
+void Diagram::PrintVerticalScale(Lum::OS::DrawInfo* draw,
+                                 size_t dayWidth,
+                                 const Lum::Base::Calendar& start)
+{
+  Lum::Base::Calendar day;
+
+  draw->PushClip(this->x+weightUnitWidth,
+                 this->y,
+                 this->width-weightUnitWidth-valueUnitWidth,
+                 this->height);
+
+  draw->PushForeground(scaleColor);
+
+  day=start;
+  int xPos=this->x+((hAdjustment->GetTop()-1)/dayWidth)*dayWidth-(hAdjustment->GetTop()-1);
+  while (xPos<this->x+(int)width) {
+    switch (mode) {
+    case modeFullDay:
+    case modeSmallDay:
+      draw->DrawLine(xPos+dayWidth-1,this->y,xPos+dayWidth-1,this->y+height-1);
+      break;
+    default:
+      break;
+    }
+
+    day.AddDays(1);
+    xPos+=dayWidth;
+  }
+
+  draw->PopForeground();
+
+  draw->PopClip();
 }
 
 /**
   Printing vertial value scale
  */
-void Diagram::PrintVerticalScale(Lum::OS::DrawInfo* draw)
+void Diagram::PrintVerticalLabel(Lum::OS::DrawInfo* draw)
 {
-  draw->PushForeground(scaleColor);
+  draw->PushForeground(labelColor);
   draw->PushFont(font);
 
   size_t step;
@@ -468,19 +519,28 @@ void Diagram::PrintVerticalScale(Lum::OS::DrawInfo* draw)
 
 void Diagram::PrintLimits(Lum::OS::DrawInfo* draw)
 {
+  // Weigth limits
   draw->PushForeground(limitColor);
-  draw->DrawLine(this->x,this->y+TransformWeight(maxWeight->Get()),
-                 this->x+weightUnitWidth-1,this->y+TransformWeight(maxWeight->Get()));
-  draw->DrawLine(this->x,this->y+TransformWeight(minWeight->Get()),
-                 this->x+weightUnitWidth-1,this->y+TransformWeight(minWeight->Get()));
+  draw->DrawLine(this->x,
+                 this->y+TransformWeight(maxWeight->Get()),
+                 this->x+weightUnitWidth-1,
+                 this->y+TransformWeight(maxWeight->Get()));
+  draw->DrawLine(this->x,
+                 this->y+TransformWeight(minWeight->Get()),
+                 this->x+weightUnitWidth-1,
+                 this->y+TransformWeight(minWeight->Get()));
   draw->PopForeground();
 
   // Value limits
   draw->PushForeground(limitColor);
-  draw->DrawLine(this->x+width-1-valueUnitWidth,this->y+TransformValue(maxValue->Get()),
-                 this->x+width-1,this->y+TransformValue(maxValue->Get()));
-  draw->DrawLine(this->x+width-1-valueUnitWidth,this->y+TransformValue(minValue->Get()),
-                 this->x+width-1,this->y+TransformValue(minValue->Get()));
+  draw->DrawLine(this->x+width-1-valueUnitWidth,
+                 this->y+TransformValue(maxValue->Get()),
+                 this->x+width-1,
+                 this->y+TransformValue(maxValue->Get()));
+  draw->DrawLine(this->x+width-1-valueUnitWidth,
+                 this->y+TransformValue(minValue->Get()),
+                 this->x+width-1,
+                 this->y+TransformValue(minValue->Get()));
   draw->PopForeground();
 }
 
@@ -553,10 +613,11 @@ void Diagram::Draw(Lum::OS::DrawInfo* draw,
   draw->PushClip(this->x,this->y,width,height);
   draw->PushClip(x,y,w,h);
 
+  PrintVerticalScale(draw,dayWidth,start);
   PrintData(draw,dayWidth,start,end);
-  PrintHorizontalScale(draw,dayWidth,start);
-  PrintVerticalScale(draw);
   PrintLimits(draw);
+  PrintHorizontalLabel(draw,dayWidth,start);
+  PrintVerticalLabel(draw);
 
   draw->PopClip();
   draw->PopClip();
