@@ -34,7 +34,7 @@ Trend::~Trend()
 
 bool Trend::SetModel(Lum::Base::Model* model)
 {
-  this->model=dynamic_cast<Lum::Model::Int*>(model);
+  this->model=dynamic_cast<Lum::Model::Long*>(model);
 
   Lum::Control::SetModel(this->model);
 
