@@ -36,10 +36,10 @@ public:
   };
 
 private:
-  Lum::OS::ColorRef  noneColor;
-  Lum::OS::ColorRef  upColor;
-  Lum::OS::ColorRef  downColor;
-  Lum::Model::IntRef model;
+  Lum::OS::ColorRef   noneColor;
+  Lum::OS::ColorRef   upColor;
+  Lum::OS::ColorRef   downColor;
+  Lum::Model::LongRef model;
 
 public:
   Trend();
